/*
 * @SamplePlot.java Version 1.1 04/23/2015
 *
 * Copyright (c) 2015 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

import java.net.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import javax.swing.*;

import brine.gui.brineSamplePlotFrame; // Brine Sample Plot Frame
import brine.gui.brineSamplePlotPanel; // Brine Sample Plot Panel
import brine.brineListStruct;          // Common Brine Data Sample
import brine.io.ReadBrineDataXMLFile;  // Read Brine Data XML File

/** Class SamplePlot
 *  <p> This Class is the starting point for the SamplePlot Applet.
 *
 *  @version 1.1 04/23/2015
 *  @author  John R. Victorine
 */

public class SamplePlot extends Applet
{
  // Runtime object

  private Runtime r = Runtime.getRuntime();

  // Web Application is runing Stand Alone Indicator

  private boolean isStandalone = false;

  private String  sKID            = new String("0"); // LAS KID
  private String  sKID_Standalone = new String("0");

  // LAS Viewer Global Variables

  private brineListStruct stList = null;

  private String        sPath    = new String(".");

  /** getParameter()
   *  <p> This method wil get a parameter value
   *  @param key = The Name of the Parameter
   *  @param def = The Object Type of the Parameter
   *  @return Parameter
   */

  public String getParameter(String key, String def)
  {
    return (isStandalone ? System.getProperty(key, def) :
            (getParameter(key) != null ? getParameter(key) : def));
  }

  /** Constructor SamplePlot()
   *  <p> This is the Constructor for this class.
   */

  public SamplePlot() {  }

  /** Method init()
   *  <p> This Method will retrieve the data values from the HTML or the main()
   *      arguments and run the Applet.
   */

  public void init()
  {
    try
    {
      sKID = this.getParameter("sKID", sKID_Standalone);
      if (sKID.equals("undefined"))
        sKID = new String("0");
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }

    try
    {
      jbInit();
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }

  /** Method jbInit()
   *  <p> This method will display the Sample Plot.
   * @throws Exception
   */

  private void jbInit() throws Exception
  {
    //brineSamplePlotPanel panel = null; // Sample Plot Panel
    brineSamplePlotFrame frame = null; // Sample Plot Frame

    // Read Brine Data

//    sPath = cmn.cmnStruct.KGS_BRINE + "key=" + sKID;
    sPath =
//    "http://chasm.kgs.ku.edu/ords/iqstrat.brine_data_pkg.getXML?key=" + sKID;
    "http://chasm.kgs.ku.edu/ords/iqstrat.co2_brine_data_pkg.getXML?key=" + sKID;
    getList();

     // Display the Sample Plot

    frame = new brineSamplePlotFrame( stList );
/*
    if (!isStandalone)
    {
      panel = new brineSamplePlotPanel( stList );
      panel.setRow(0);

      this.setLayout(new BorderLayout());
      this.add(panel, BorderLayout.CENTER);
    }
    else
    {
      JFrame frame = new JFrame();

      frame.setTitle("Brine Sample Plot " + sKID);
      panel = new brineSamplePlotPanel( stList );
      panel.setRow(0);
      frame.getContentPane().add(panel, null);

      // Set the Size and Display the Frame

      frame.setSize(775, 700);
      Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
      frame.setLocation((d.width - frame.getSize().width)/2,
                        (d.height - frame.getSize().height)/2);

      frame.setResizable(false);
      frame.setVisible(true);
    }
*/
  }

  /* ======================================================================= *
   * ------------------------ READ DATA XML METHODS ------------------------ *
   * ======================================================================= */

  /** Method getList()
   * <p> This method will get the KGS Database for measured sections that fit
   *     the constraint passed in.
   */

  private void getList()
  {
	ReadBrineDataXMLFile pRead =
	  new ReadBrineDataXMLFile(brine.io.ReadBrineDataXMLFile.URL);
    stList = pRead.Process( sPath );
  }

  /* ======================================================================= *
   * --------------------------- APPLET METHODS ---------------------------- *
   * ======================================================================= */

  /** Method start()
   *  <p> This method will start the applet
   */

  public void start() { }

  /** Method stop()
   *  <p> This method will stop the applet
   */

  public void stop() { }

  /** Method destroy()
   *  <p> This method will destroy the applet
   */

  public void destroy() { }

  /** Method getAppletInfo()
   *  <p> This method will return Applet information
   *  @return - Biostratigraphy Profile Plot
   */

  public String getAppletInfo() { return ("LAS IO Applet"); }

  /** Method getParameterInfo()
   *  <p> This method will get the parameter info
   *  @return pinfo - Array of Parameters Expected.
   */

  public String[][] getParameterInfo()
  {
    String[][] pinfo = { {"sKID",  "String", "Brine Sample Primary Key"}, };

    return pinfo;
  }

  /** Method main()
   *  <p> This method will allow this Module to run either as an Application or
   *      an Applet.
   *  @param args = The Arguments passed in to query for the production data
   */

  public static void main(String[] args)
  {
    SamplePlot applet = new SamplePlot();

    applet.isStandalone = true;
    applet.sKID_Standalone = new String("0");
    if (args.length > 0)
      applet.sKID_Standalone = new String(args[0]);

    applet.init();
    applet.start();
  }
}


/*
 *  @version 1.1 04/23/2015
 *  @author  John Victorine
 */
